antares.apps.initialsettings.manager package
============================================

Submodules
----------

antares.apps.initialsettings.manager.initial\_settings\_loader module
---------------------------------------------------------------------

.. automodule:: antares.apps.initialsettings.manager.initial_settings_loader
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.initialsettings.manager.isic\_loader module
--------------------------------------------------------

.. automodule:: antares.apps.initialsettings.manager.isic_loader
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.initialsettings.manager
   :members:
   :undoc-members:
   :show-inheritance:
